@@ -20,15 +20,14 @@ import socket
 import netaddr
 from neutron.agent.linux import ip_lib
 from neutron.agent.linux import utils as linux_utils
-from neutron.common import exceptions
 from neutron.common import utils as n_utils
-from neutron.i18n import _LI, _LE, _LW
 from neutron.plugins.common import constants
+from neutron_lib import exceptions
 from oslo_config import cfg
 from oslo_log import log as logging
 from oslo_utils import excutils
-from oslo_utils import importutils
 
+from neutron_lbaas._i18n import _, _LI, _LE, _LW
 from neutron_lbaas.agent import agent_device_driver
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 from neutron_lbaas.services.loadbalancer import data_models
@@ -61,14 +60,16 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
         self.state_path = os.path.join(
             self.conf.haproxy.loadbalancer_state_path, STATE_PATH_V2_APPEND)
         try:
-            vif_driver = importutils.import_object(conf.interface_driver, conf)
+            vif_driver_class = n_utils.load_class_by_alias_or_classname(
+                'neutron.interface_drivers',
+                conf.interface_driver)
         except ImportError:
             with excutils.save_and_reraise_exception():
                 msg = (_('Error importing interface driver: %s')
                        % conf.interface_driver)
                 LOG.error(msg)
 
-        self.vif_driver = vif_driver
+        self.vif_driver = vif_driver_class(conf)
         self.deployed_loadbalancers = {}
         self._loadbalancer = LoadBalancerManager(self)
         self._listener = ListenerManager(self)
@@ -153,15 +154,15 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
             lb_stats['members'] = self._get_servers_stats(parsed_stats)
             return lb_stats
         else:
-            LOG.warn(_LW('Stats socket not found for loadbalancer %s') %
-                     loadbalancer_id)
+            LOG.warning(_LW('Stats socket not found for loadbalancer %s'),
+                        loadbalancer_id)
             return {}
 
     @n_utils.synchronized('haproxy-driver')
     def deploy_instance(self, loadbalancer):
         """Deploys loadbalancer if necessary
 
-        :return: True if loadbalancer was deployed, False otherwise
+        :returns: True if loadbalancer was deployed, False otherwise
         """
         if not self.deployable(loadbalancer):
             LOG.info(_LI("Loadbalancer %s is not deployable.") %
@@ -227,7 +228,7 @@ class HaproxyNSDriver(agent_device_driver.AgentDeviceDriver):
 
             return self._parse_stats(raw_stats)
         except socket.error as e:
-            LOG.warn(_LW('Error while connecting to stats socket: %s'), e)
+            LOG.warning(_LW('Error while connecting to stats socket: %s'), e)
             return {}
 
     def _parse_stats(self, raw_stats):
@@ -418,14 +419,17 @@ class ListenerManager(agent_device_driver.BaseListenerManager):
 class PoolManager(agent_device_driver.BasePoolManager):
 
     def update(self, old_pool, new_pool):
-        self.driver.loadbalancer.refresh(new_pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(new_pool.loadbalancer)
 
     def create(self, pool):
-        self.driver.loadbalancer.refresh(pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(pool.loadbalancer)
 
     def delete(self, pool):
-        loadbalancer = pool.listener.loadbalancer
-        pool.listener.default_pool = None
+        loadbalancer = pool.loadbalancer
+        for l in loadbalancer.listeners:
+            if l.default_pool == pool:
+                l.default_pool = None
+        # TODO(sbalukoff): Will need to do this or L7Policies as well
         # just refresh because haproxy is fine if only frontend is listed
         self.driver.loadbalancer.refresh(loadbalancer)
 
@@ -440,27 +444,27 @@ class MemberManager(agent_device_driver.BaseMemberManager):
         pool.members.pop(index_to_remove)
 
     def update(self, old_member, new_member):
-        self.driver.loadbalancer.refresh(new_member.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(new_member.pool.loadbalancer)
 
     def create(self, member):
-        self.driver.loadbalancer.refresh(member.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(member.pool.loadbalancer)
 
     def delete(self, member):
         self._remove_member(member.pool, member.id)
-        self.driver.loadbalancer.refresh(member.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(member.pool.loadbalancer)
 
 
 class HealthMonitorManager(agent_device_driver.BaseHealthMonitorManager):
 
     def update(self, old_hm, new_hm):
-        self.driver.loadbalancer.refresh(new_hm.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(new_hm.pool.loadbalancer)
 
     def create(self, hm):
-        self.driver.loadbalancer.refresh(hm.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(hm.pool.loadbalancer)
 
     def delete(self, hm):
         hm.pool.healthmonitor = None
-        self.driver.loadbalancer.refresh(hm.pool.listener.loadbalancer)
+        self.driver.loadbalancer.refresh(hm.pool.loadbalancer)
 
 
 def kill_pids_in_file(pid_path):
