@@ -24,11 +24,12 @@ from neutron.api import extensions
 from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import base
 from neutron.api.v2 import resource_helper
-from neutron.common import exceptions as nexception
 from neutron import manager
 from neutron.plugins.common import constants
 from neutron.services import service_base
+from neutron_lib import exceptions as nexception
 
+from neutron_lbaas._i18n import _
 from neutron_lbaas.services.loadbalancer import constants as lb_const
 
 LOADBALANCERV2_PREFIX = "/lbaas"
@@ -102,11 +103,6 @@ class DriverError(nexception.NeutronException):
     message = _("An error happened in the driver")
 
 
-class LBConfigurationUnsupported(nexception.NeutronException):
-    message = _("Load balancer %(load_balancer_id)s configuration is not "
-                "supported by driver %(driver_name)s")
-
-
 class SessionPersistenceConfigurationInvalid(nexception.BadRequest):
     message = _("Session Persistence Invalid: %(msg)s")
 
@@ -127,6 +123,14 @@ class CertManagerError(nexception.NeutronException):
     message = _("Could not process TLS container %(ref)s, %(reason)s")
 
 
+class ProviderFlavorConflict(nexception.Conflict):
+    message = _("Cannot specify both a flavor and a provider")
+
+
+class FlavorsPluginNotLoaded(nexception.NotFound):
+    message = _("Flavors plugin not found")
+
+
 def _validate_connection_limit(data, min_value=lb_const.MIN_CONNECT_VALUE):
     if int(data) < min_value:
         msg = (_("'%(data)s' is not a valid value, "
@@ -177,7 +181,11 @@ RESOURCE_ATTRIBUTE_MAP = {
         'provisioning_status': {'allow_post': False, 'allow_put': False,
                                 'is_visible': True},
         'operating_status': {'allow_post': False, 'allow_put': False,
-                             'is_visible': True}
+                             'is_visible': True},
+        'flavor_id': {'allow_post': True, 'allow_put': False,
+                      'is_visible': True,
+                      'validate': {'type:string': attr.NAME_MAX_LEN},
+                      'default': attr.ATTR_NOT_SPECIFIED}
     },
     'listeners': {
         'id': {'allow_post': False, 'allow_put': False,
@@ -336,7 +344,11 @@ RESOURCE_ATTRIBUTE_MAP = {
         'admin_state_up': {'allow_post': True, 'allow_put': True,
                            'default': True,
                            'convert_to': attr.convert_to_boolean,
-                           'is_visible': True}
+                           'is_visible': True},
+        'name': {'allow_post': True, 'allow_put': True,
+                 'validate': {'type:string': attr.NAME_MAX_LEN},
+                 'default': '',
+                 'is_visible': True}
     }
 }
 
@@ -373,7 +385,10 @@ SUB_RESOURCE_ATTRIBUTE_MAP = {
             'subnet_id': {'allow_post': True, 'allow_put': False,
                           'validate': {'type:uuid': None},
                           'is_visible': True},
-
+            'name': {'allow_post': True, 'allow_put': True,
+                     'validate': {'type:string': attr.NAME_MAX_LEN},
+                     'default': '',
+                     'is_visible': True},
         }
     }
 }
@@ -433,6 +448,7 @@ class Loadbalancerv2(extensions.ExtensionDescriptor):
         action_map = {'loadbalancer': {'stats': 'GET', 'statuses': 'GET'}}
         plural_mappings['members'] = 'member'
         plural_mappings['sni_container_refs'] = 'sni_container_ref'
+        plural_mappings['sni_container_ids'] = 'sni_container_id'
         attr.PLURALS.update(plural_mappings)
         resources = resource_helper.build_resource_info(
             plural_mappings,
@@ -446,6 +462,7 @@ class Loadbalancerv2(extensions.ExtensionDescriptor):
             # Special handling needed for sub-resources with 'y' ending
             # (e.g. proxies -> proxy)
             resource_name = collection_name[:-1]
+
             parent = SUB_RESOURCE_ATTRIBUTE_MAP[collection_name].get('parent')
             params = SUB_RESOURCE_ATTRIBUTE_MAP[collection_name].get(
                 'parameters')
@@ -611,3 +628,43 @@ class LoadBalancerPluginBaseV2(service_base.ServicePluginBase):
     @abc.abstractmethod
     def statuses(self, context, loadbalancer_id):
         pass
+
+    def get_l7policies(self, context, filters=None, fields=None):
+        pass
+
+    @abc.abstractmethod
+    def get_l7policy(self, context, id, fields=None):
+        pass
+
+    @abc.abstractmethod
+    def create_l7policy(self, context, l7policy):
+        pass
+
+    @abc.abstractmethod
+    def update_l7policy(self, context, id, l7policy):
+        pass
+
+    @abc.abstractmethod
+    def delete_l7policy(self, context, id):
+        pass
+
+    @abc.abstractmethod
+    def get_l7policy_rules(self, context, l7policy_id,
+                           filters=None, fields=None):
+        pass
+
+    @abc.abstractmethod
+    def get_l7policy_rule(self, context, id, l7policy_id, fields=None):
+        pass
+
+    @abc.abstractmethod
+    def create_l7policy_rule(self, context, rule, l7policy_id):
+        pass
+
+    @abc.abstractmethod
+    def update_l7policy_rule(self, context, id, rule, l7policy_id):
+        pass
+
+    @abc.abstractmethod
+    def delete_l7policy_rule(self, context, id, l7policy_id):
+        pass
