@@ -1,4 +1,5 @@
-# Copyright 2015 Rackspace
+# Copyright 2015, 2016 Rackspace Inc.
+# All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,16 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import os
 import time
 
-from neutron.i18n import _, _LI
 from oslo_log import log as logging
-from tempest_lib import exceptions
+from tempest.api.network import base
+from tempest import config
+from tempest.lib import exceptions
 
-# from neutron_lbaas.tests.tempest.lib import clients as tempest_clients
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.v1.api import base
+from neutron_lbaas._i18n import _, _LI
 from neutron_lbaas.tests.tempest.v2.clients import health_monitors_client
 from neutron_lbaas.tests.tempest.v2.clients import listeners_client
 from neutron_lbaas.tests.tempest.v2.clients import load_balancers_client
@@ -32,11 +31,6 @@ CONF = config.CONF
 
 LOG = logging.getLogger(__name__)
 
-# Use local tempest conf if one is available.
-# This usually means we're running tests outside of devstack
-if os.path.exists('./tests/tempest/etc/dev_tempest.conf'):
-    CONF.set_config_path('./tests/tempest/etc/dev_tempest.conf')
-
 
 def _setup_client_args(auth_provider):
     """Set up ServiceClient arguments using config settings. """
@@ -136,7 +130,7 @@ class BaseTestCase(base.BaseNetworkTest):
             cls._wait_for_load_balancer_status(lb.get('id'))
 
         cls._lbs_to_delete.append(lb.get('id'))
-        port = cls.client.show_port(lb['vip_port_id'])
+        port = cls.ports_client.show_port(lb['vip_port_id'])
         cls.ports.append(port['port'])
         return lb
 
@@ -258,28 +252,28 @@ class BaseTestCase(base.BaseNetworkTest):
                 cls.load_balancer.get('id'))
         return pool
 
-    @classmethod
-    def _create_health_monitor(cls, wait=True, **health_monitor_kwargs):
-        hm = cls.health_monitors_client.create_health_monitor(
+    def _create_health_monitor(self, wait=True, cleanup=True,
+                               **health_monitor_kwargs):
+        hm = self.health_monitors_client.create_health_monitor(
             **health_monitor_kwargs)
+        if cleanup:
+            self.addCleanup(self._delete_health_monitor, hm.get('id'))
         if wait:
-            cls._wait_for_load_balancer_status(cls.load_balancer.get('id'))
+            self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         return hm
 
-    @classmethod
-    def _delete_health_monitor(cls, health_monitor_id, wait=True):
-        cls.health_monitors_client.delete_health_monitor(health_monitor_id)
+    def _delete_health_monitor(self, health_monitor_id, wait=True):
+        self.health_monitors_client.delete_health_monitor(health_monitor_id)
         if wait:
-            cls._wait_for_load_balancer_status(cls.load_balancer.get('id'))
+            self._wait_for_load_balancer_status(self.load_balancer.get('id'))
 
-    @classmethod
-    def _update_health_monitor(cls, health_monitor_id, wait=True,
+    def _update_health_monitor(self, health_monitor_id, wait=True,
                                **health_monitor_kwargs):
-        health_monitor = cls.health_monitors_client.update_health_monitor(
+        health_monitor = self.health_monitors_client.update_health_monitor(
             health_monitor_id, **health_monitor_kwargs)
         if wait:
-            cls._wait_for_load_balancer_status(
-                cls.load_balancer.get('id'))
+            self._wait_for_load_balancer_status(
+                self.load_balancer.get('id'))
         return health_monitor
 
     @classmethod
