@@ -1,4 +1,4 @@
-# Copyright 2015 Rackspace US Inc.
+# Copyright 2015, 2016 Rackspace US Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,18 +13,15 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_log import log as logging
-from tempest_lib.common.utils import data_utils
-from tempest_lib import exceptions
+from tempest import config
+from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions as ex
+from tempest import test
 
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.lib import test
 from neutron_lbaas.tests.tempest.v2.api import base
 
 CONF = config.CONF
 
-LOG = logging.getLogger(__name__)
-
 
 class ListenersTestJSON(base.BaseTestCase):
 
@@ -58,8 +55,7 @@ class ListenersTestJSON(base.BaseTestCase):
         cls.create_listener_kwargs = {'loadbalancer_id': cls.load_balancer_id,
                                       'protocol': cls.protocol,
                                       'protocol_port': cls.port}
-        cls.listener = cls._create_listener(
-            **cls.create_listener_kwargs)
+        cls.listener = cls._create_listener(**cls.create_listener_kwargs)
         cls.listener_id = cls.listener['id']
 
     @test.attr(type='smoke')
@@ -88,6 +84,7 @@ class ListenersTestJSON(base.BaseTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
@@ -96,7 +93,6 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertIn(self.listener, listeners)
         self.assertIn(new_listener, listeners)
         self.assertNotEqual(self.listener, new_listener)
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='smoke')
     def test_create_listener(self):
@@ -106,6 +102,7 @@ class ListenersTestJSON(base.BaseTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
@@ -113,12 +110,11 @@ class ListenersTestJSON(base.BaseTestCase):
             new_listener_id)
         self.assertEqual(new_listener, listener)
         self.assertNotEqual(self.listener, new_listener)
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='negative')
     def test_create_listener_missing_field_loadbalancer(self):
         """Test create listener with a missing required field loadbalancer"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
                           protocol=self.protocol)
@@ -128,7 +124,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_missing_field_protocol(self):
         """Test create listener with a missing required field protocol"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port)
@@ -138,7 +134,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_missing_field_protocol_port(self):
         """Test create listener with a missing required field protocol_port"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol=self.protocol)
@@ -153,6 +149,7 @@ class ListenersTestJSON(base.BaseTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
@@ -160,12 +157,11 @@ class ListenersTestJSON(base.BaseTestCase):
             new_listener_id)
         self.assertEqual(new_listener, listener)
         self.assertTrue(new_listener['admin_state_up'])
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='negative')
     def test_create_listener_invalid_load_balancer_id(self):
         """Test create listener with an invalid load_balancer_id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id="234*",
                           protocol_port=self.port,
@@ -176,7 +172,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_protocol(self):
         """Test create listener with an invalid protocol"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -187,7 +183,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_protocol_port(self):
         """Test create listener with an invalid protocol_port"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port="9999999",
@@ -198,7 +194,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_admin_state_up(self):
         """Test update listener with an invalid admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
                           protocol=self.protocol,
@@ -209,7 +205,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_tenant_id(self):
         """Test create listener with an invalid tenant id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -221,7 +217,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_name(self):
         """Test create listener with an invalid name"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -233,7 +229,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_invalid_description(self):
         """Test create listener with an invalid description"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -247,7 +243,7 @@ class ListenersTestJSON(base.BaseTestCase):
         """Test create listener with an invalid value for connection
         _limit field
         """
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -259,7 +255,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_empty_load_balancer_id(self):
         """Test create listener with an empty load_balancer_id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id="",
                           protocol_port=self.port,
@@ -270,7 +266,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_empty_protocol(self):
         """Test create listener with an empty protocol"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -281,7 +277,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_empty_protocol_port(self):
         """Test create listener with an empty protocol_port"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port="",
@@ -292,7 +288,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_empty_admin_state_up(self):
         """Test update listener with an empty  admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           protocol_port=self.port,
                           protocol=self.protocol,
@@ -303,7 +299,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_empty_tenant_id(self):
         """Test create listener with an empty tenant id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -321,13 +317,13 @@ class ListenersTestJSON(base.BaseTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
         listener = self.listeners_client.get_listener(
             new_listener_id)
         self.assertEqual(new_listener, listener)
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='smoke')
     def test_create_listener_empty_description(self):
@@ -338,20 +334,20 @@ class ListenersTestJSON(base.BaseTestCase):
         new_listener = self._create_listener(
             **create_new_listener_kwargs)
         new_listener_id = new_listener['id']
+        self.addCleanup(self._delete_listener, new_listener_id)
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
             listener_ids=[self.listener_id, new_listener_id])
         listener = self.listeners_client.get_listener(
             new_listener_id)
         self.assertEqual(new_listener, listener)
-        self._delete_listener(new_listener_id)
 
     @test.attr(type='negative')
     def test_create_listener_empty_connection_limit(self):
         """Test create listener with an empty connection
         _limit field
         """
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           loadbalancer_id=self.load_balancer_id,
                           protocol_port=self.port,
@@ -363,7 +359,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_create_listener_incorrect_attribute(self):
         """Test create a listener with an extra, incorrect field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._create_listener,
                           incorrect_attribute="incorrect_attribute",
                           **self.create_listener_kwargs)
@@ -384,7 +380,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_invalid_tenant_id(self):
         """Test update listener with an invalid tenant id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           tenant_id="&^%123")
@@ -394,7 +390,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_invalid_admin_state_up(self):
         """Test update a listener with an invalid admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           admin_state_up="$23")
@@ -404,7 +400,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_invalid_name(self):
         """Test update a listener with an invalid name"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           name='a' * 256)
@@ -414,7 +410,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_invalid_description(self):
         """Test update a listener with an invalid description"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           description='a' * 256)
@@ -424,7 +420,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_invalid_connection_limit(self):
         """Test update a listener with an invalid connection_limit"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           connection_limit="$23")
@@ -434,7 +430,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_incorrect_attribute(self):
         """Test update a listener with an extra, incorrect field"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           name="listener_name123",
@@ -505,7 +501,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_empty_tenant_id(self):
         """Test update listener with an empty tenant id"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           tenant_id="")
@@ -515,7 +511,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_empty_admin_state_up(self):
         """Test update a listener with an empty admin_state_up"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           admin_state_up="")
@@ -547,7 +543,7 @@ class ListenersTestJSON(base.BaseTestCase):
     @test.attr(type='negative')
     def test_update_listener_empty_connection_limit(self):
         """Test update a listener with an empty connection_limit"""
-        self.assertRaises(exceptions.BadRequest,
+        self.assertRaises(ex.BadRequest,
                           self._update_listener,
                           listener_id=self.listener_id,
                           connection_limit="")
@@ -559,8 +555,7 @@ class ListenersTestJSON(base.BaseTestCase):
         """Test delete listener"""
         create_new_listener_kwargs = self.create_listener_kwargs
         create_new_listener_kwargs['protocol_port'] = 8083
-        new_listener = self._create_listener(
-            **create_new_listener_kwargs)
+        new_listener = self._create_listener(**create_new_listener_kwargs)
         new_listener_id = new_listener['id']
         self._check_status_tree(
             load_balancer_id=self.load_balancer_id,
@@ -570,6 +565,6 @@ class ListenersTestJSON(base.BaseTestCase):
         self.assertEqual(new_listener, listener)
         self.assertNotEqual(self.listener, new_listener)
         self._delete_listener(new_listener_id)
-        self.assertRaises(exceptions.NotFound,
+        self.assertRaises(ex.NotFound,
                           self.listeners_client.get_listener,
                           new_listener_id)
