@@ -1,4 +1,5 @@
-#    Copyright 2015 Rackspace
+# Copyright 2016 Rackspace Inc.
+# All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
@@ -12,10 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from tempest_lib.common.utils import data_utils
-from tempest_lib import exceptions as ex
+from tempest.lib.common.utils import data_utils
+from tempest.lib import exceptions as ex
+from tempest import test
 
-from neutron_lbaas.tests.tempest.lib import test
 from neutron_lbaas.tests.tempest.v2.api import base
 
 PROTOCOL_PORT = 80
@@ -56,7 +57,7 @@ class TestPools(base.BaseTestCase):
         PROTOCOL_PORT += 1
 
     def _prepare_and_create_pool(self, protocol=None, lb_algorithm=None,
-                                 listener_id=None, **kwargs):
+                                 listener_id=None, cleanup=True, **kwargs):
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.increment_protocol_port()
         if not protocol:
@@ -74,6 +75,8 @@ class TestPools(base.BaseTestCase):
                                      listener_id=listener_id,
                                      wait=True,
                                      **kwargs)
+        if cleanup:
+            self.addCleanup(self._delete_pool, response['id'])
         return response
 
     @test.attr(type='smoke')
@@ -90,7 +93,6 @@ class TestPools(base.BaseTestCase):
         pools = self.pools_client.list_pools()
         self.assertEqual(1, len(pools))
         self.assertIn(new_pool, pools)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_list_pools_two(self):
@@ -101,9 +103,6 @@ class TestPools(base.BaseTestCase):
         self.assertEqual(2, len(pools))
         self.assertIn(new_pool1, pools)
         self.assertIn(new_pool2, pools)
-        self._delete_pool(new_pool1.get('id'))
-        self._wait_for_load_balancer_status(self.load_balancer.get('id'))
-        self._delete_pool(new_pool2.get('id'))
 
     @test.attr(type='smoke')
     def test_get_pool(self):
@@ -111,7 +110,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool(self):
@@ -119,7 +117,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_create_pool_missing_required_fields(self):
@@ -139,7 +136,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.get_pool(new_pool.get('id'))
         pool_tenant = pool['tenant_id']
         self.assertEqual(tenant_id, pool_tenant)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_create_pool_missing_protocol_field(self):
@@ -148,6 +144,7 @@ class TestPools(base.BaseTestCase):
         listener = self.listeners_client.create_listener(
             loadbalancer_id=self.load_balancer.get('id'),
             protocol='HTTP', protocol_port=PROTOCOL_PORT)
+        self.addCleanup(self._delete_listener, listener['id'])
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         listener_id = listener.get('id')
         tenant_id = self.subnet.get('tenant_id')
@@ -163,6 +160,7 @@ class TestPools(base.BaseTestCase):
         listener = self.listeners_client.create_listener(
             loadbalancer_id=self.load_balancer.get('id'),
             protocol='HTTP', protocol_port=PROTOCOL_PORT)
+        self.addCleanup(self._delete_listener, listener['id'])
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         listener_id = listener.get('id')
         tenant_id = self.subnet.get('tenant_id')
@@ -188,7 +186,6 @@ class TestPools(base.BaseTestCase):
         pool_initial = self.pools_client.get_pool(new_pool.get('id'))
         desc = pool_initial.get('description')
         self.assertEqual(desc, "")
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool_missing_name_field(self):
@@ -197,7 +194,6 @@ class TestPools(base.BaseTestCase):
         pool_initial = self.pools_client.get_pool(new_pool.get('id'))
         name = pool_initial.get('name')
         self.assertEqual(name, "")
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool_missing_admin_state_up_field(self):
@@ -206,7 +202,6 @@ class TestPools(base.BaseTestCase):
         pool_initial = self.pools_client.get_pool(new_pool.get('id'))
         state = pool_initial.get('admin_state_up')
         self.assertEqual(state, True)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool_missing_session_pers_field(self):
@@ -215,7 +210,6 @@ class TestPools(base.BaseTestCase):
         pool_initial = self.pools_client.get_pool(new_pool.get('id'))
         sess = pool_initial.get('session_persistence')
         self.assertIsNone(sess)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_create_pool_invalid_protocol(self):
@@ -268,6 +262,7 @@ class TestPools(base.BaseTestCase):
         listener = self.listeners_client.create_listener(
             loadbalancer_id=self.load_balancer.get('id'),
             protocol='HTTP', protocol_port=PROTOCOL_PORT)
+        self.addCleanup(self._delete_listener, listener['id'])
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         listener_id = listener.get('id')
         self.assertRaises(ex.BadRequest, self._create_pool,
@@ -302,7 +297,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.get_pool(new_pool.get('id'))
         pool_desc = pool.get('description')
         self.assertEqual(pool_desc, '')
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool_empty_name_field(self):
@@ -311,7 +305,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.get_pool(new_pool.get('id'))
         pool_name = pool.get('name')
         self.assertEqual(pool_name, '')
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_create_pool_empty_protocol(self):
@@ -407,7 +400,6 @@ class TestPools(base.BaseTestCase):
             session_persistence={'type': 'HTTP_COOKIE'})
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_create_pool_with_session_persistence_app_cookie(self):
@@ -417,7 +409,6 @@ class TestPools(base.BaseTestCase):
                                  'cookie_name': 'sessionId'})
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_create_pool_with_session_persistence_redundant_cookie_name(self):
@@ -451,7 +442,6 @@ class TestPools(base.BaseTestCase):
                                  description=desc,
                                  wait=True)
         self.assertEqual(desc, pool.get('description'))
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_missing_name(self):
@@ -462,7 +452,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.update_pool(new_pool.get('id'))
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.assertEqual(name, pool.get('name'))
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_missing_description(self):
@@ -473,7 +462,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.update_pool(new_pool.get('id'))
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.assertEqual(desc, pool.get('description'))
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_missing_admin_state_up(self):
@@ -484,7 +472,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.update_pool(new_pool.get('id'))
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.assertEqual(admin, pool.get('admin_state_up'))
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_missing_session_persistence(self):
@@ -492,10 +479,8 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         pool_initial = self.pools_client.get_pool(new_pool.get('id'))
         sess_pers = pool_initial.get('session_persistence')
-        pool = self.pools_client.update_pool(new_pool.get('id'))
+        pool = self._update_pool(new_pool.get('id'))
         self.assertAlmostEqual(sess_pers, pool.get('session_persistence'))
-        self._wait_for_load_balancer_status(self.load_balancer.get('id'))
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_invalid_name(self):
@@ -503,7 +488,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'), name='n' * 256)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_invalid_desc(self):
@@ -512,7 +496,6 @@ class TestPools(base.BaseTestCase):
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'),
                           description='d' * 256)
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_invalid_admin_state_up(self):
@@ -520,7 +503,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'), admin_state_up='hello')
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_invalid_session_persistence(self):
@@ -529,7 +511,6 @@ class TestPools(base.BaseTestCase):
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'),
                           session_persistence={'type': 'Hello'})
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_empty_name(self):
@@ -538,7 +519,6 @@ class TestPools(base.BaseTestCase):
         pool = self.pools_client.update_pool(new_pool.get('id'), name="")
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.assertEqual(pool.get('name'), "")
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_update_pool_empty_description(self):
@@ -548,7 +528,6 @@ class TestPools(base.BaseTestCase):
                                              description="")
         self._wait_for_load_balancer_status(self.load_balancer.get('id'))
         self.assertEqual(pool.get('description'), "")
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_empty_admin_state_up(self):
@@ -556,7 +535,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'), admin_state_up="")
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_empty_session_persistence(self):
@@ -565,7 +543,6 @@ class TestPools(base.BaseTestCase):
         self.assertRaises(ex.BadRequest, self.pools_client.update_pool,
                           new_pool.get('id'),
                           session_persistence="")
-        self.pools_client.delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_invalid_attribute(self):
@@ -573,7 +550,6 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         self.assertRaises(ex.BadRequest, self._update_pool,
                           new_pool.get('id'), lb_algorithm='ROUNDED')
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='negative')
     def test_update_pool_incorrect_attribute(self):
@@ -581,12 +557,11 @@ class TestPools(base.BaseTestCase):
         new_pool = self._prepare_and_create_pool()
         self.assertRaises(ex.BadRequest, self._update_pool,
                           new_pool.get('id'), protocol='HTTPS')
-        self._delete_pool(new_pool.get('id'))
 
     @test.attr(type='smoke')
     def test_delete_pool(self):
         """Test delete pool"""
-        new_pool = self._prepare_and_create_pool()
+        new_pool = self._prepare_and_create_pool(cleanup=False)
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
         self._delete_pool(new_pool.get('id'))
@@ -596,7 +571,7 @@ class TestPools(base.BaseTestCase):
     @test.attr(type='smoke')
     def test_delete_invalid_pool(self):
         """Test delete pool that doesn't exist"""
-        new_pool = self._prepare_and_create_pool()
+        new_pool = self._prepare_and_create_pool(cleanup=False)
         pool = self.pools_client.get_pool(new_pool.get('id'))
         self.assertEqual(new_pool, pool)
         self._delete_pool(new_pool.get('id'))
