@@ -1,4 +1,5 @@
 # Copyright 2015 Hewlett-Packard Development Company, L.P.
+# Copyright 2016 Rackspace Inc.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -13,30 +14,57 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import cookielib
+import shlex
 import socket
+import subprocess
 import tempfile
 import time
 
+from oslo_log import log as logging
 import six
 from six.moves.urllib import error
 from six.moves.urllib import request as urllib2
-from tempest_lib import exceptions as lib_exc
+from tempest.common import waiters
+from tempest import config
+from tempest import exceptions
+from tempest.lib import exceptions as lib_exc
+from tempest.scenario import manager
+from tempest.services.network import resources as net_resources
+from tempest import test
 
-from neutron_lbaas.tests.tempest.lib.common import commands
-from neutron_lbaas.tests.tempest.lib import config
-from neutron_lbaas.tests.tempest.lib import exceptions
-from neutron_lbaas.tests.tempest.lib.services.network import resources as \
-    net_resources
-from neutron_lbaas.tests.tempest.lib import test
+from neutron_lbaas._i18n import _
 from neutron_lbaas.tests.tempest.v2.clients import health_monitors_client
 from neutron_lbaas.tests.tempest.v2.clients import listeners_client
 from neutron_lbaas.tests.tempest.v2.clients import load_balancers_client
 from neutron_lbaas.tests.tempest.v2.clients import members_client
 from neutron_lbaas.tests.tempest.v2.clients import pools_client
-from neutron_lbaas.tests.tempest.v2.scenario import manager
 
 config = config.CONF
 
+LOG = logging.getLogger(__name__)
+
+
+def _setup_config_args(auth_provider):
+    """Set up ServiceClient arguments using config settings. """
+    service = config.network.catalog_type
+    region = config.network.region or config.identity.region
+    endpoint_type = config.network.endpoint_type
+    build_interval = config.network.build_interval
+    build_timeout = config.network.build_timeout
+
+    # The disable_ssl appears in identity
+    disable_ssl_certificate_validation = (
+        config.identity.disable_ssl_certificate_validation)
+    ca_certs = None
+
+    # Trace in debug section
+    trace_requests = config.debug.trace_requests
+
+    return [auth_provider, service, region, endpoint_type, build_interval,
+            build_timeout, disable_ssl_certificate_validation, ca_certs,
+            trace_requests]
+
 
 class BaseTestCase(manager.NetworkScenarioTest):
 
@@ -51,7 +79,6 @@ class BaseTestCase(manager.NetworkScenarioTest):
         self.port1 = 80
         self.port2 = 88
         self.num = 50
-        self.server_ips = {}
         self.server_fixed_ips = {}
 
         self._create_security_group_for_test()
@@ -59,7 +86,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
 
         mgr = self.get_client_manager()
         auth_provider = mgr.auth_provider
-        self.client_args = [auth_provider, 'network', 'regionOne']
+        self.client_args = _setup_config_args(auth_provider)
 
         self.load_balancers_client = (
             load_balancers_client.LoadBalancersClientJSON(*self.client_args))
@@ -150,9 +177,14 @@ class BaseTestCase(manager.NetworkScenarioTest):
             ],
             'key_name': keypair['name'],
             'security_groups': security_groups,
+            'name': name
         }
         net_name = self.network['name']
-        server = self.create_server(name=name, create_kwargs=create_kwargs)
+        server = self.create_server(**create_kwargs)
+        waiters.wait_for_server_status(self.servers_client,
+                                       server['id'], 'ACTIVE')
+        server = self.servers_client.show_server(server['id'])
+        server = server['server']
         self.servers_keypairs[server['id']] = keypair
         if (config.network.public_network_id and not
                 config.network.tenant_networks_reachable):
@@ -181,14 +213,16 @@ class BaseTestCase(manager.NetworkScenarioTest):
     def _stop_server(self):
         for name, value in six.iteritems(self.servers):
             if name == 'primary':
-                self.servers_client.stop(value)
-                self.servers_client.wait_for_server_status(value, 'SHUTOFF')
+                self.servers_client.stop_server(value)
+                waiters.wait_for_server_status(self.servers_client,
+                                               value, 'SHUTOFF')
 
     def _start_server(self):
         for name, value in six.iteritems(self.servers):
             if name == 'primary':
                 self.servers_client.start(value)
-                self.servers_client.wait_for_server_status(value, 'ACTIVE')
+                waiters.wait_for_server_status(self.servers_client,
+                                               value, 'ACTIVE')
 
     def _start_servers(self):
         """
@@ -198,27 +232,30 @@ class BaseTestCase(manager.NetworkScenarioTest):
         """
         for server_id, ip in six.iteritems(self.server_ips):
             private_key = self.servers_keypairs[server_id]['private_key']
-            server_name = self.servers_client.get_server(server_id)['name']
-            username = config.scenario.ssh_user
+            server = self.servers_client.show_server(server_id)['server']
+            server_name = server['name']
+            username = config.validation.image_ssh_user
             ssh_client = self.get_remote_client(
-                server_or_ip=ip,
+                ip_address=ip,
                 private_key=private_key)
 
             # Write a backend's response into a file
             resp = ('echo -ne "HTTP/1.1 200 OK\r\nContent-Length: 7\r\n'
-                    'Connection: close\r\nContent-Type: text/html; '
-                    'charset=UTF-8\r\n\r\n%s"; cat >/dev/null')
+                    'Set-Cookie:JSESSIONID=%(s_id)s\r\nConnection: close\r\n'
+                    'Content-Type: text/html; '
+                    'charset=UTF-8\r\n\r\n%(server)s"; cat >/dev/null')
 
             with tempfile.NamedTemporaryFile() as script:
-                script.write(resp % server_name)
+                script.write(resp % {'s_id': server_name[-1],
+                                     'server': server_name})
                 script.flush()
                 with tempfile.NamedTemporaryFile() as key:
                     key.write(private_key)
                     key.flush()
-                    commands.copy_file_to_host(script.name,
-                                               "/tmp/script1",
-                                               ip,
-                                               username, key.name)
+                    self.copy_file_to_host(script.name,
+                                           "/tmp/script1",
+                                           ip,
+                                           username, key.name)
 
             # Start netcat
             start_server = ('while true; do '
@@ -230,14 +267,15 @@ class BaseTestCase(manager.NetworkScenarioTest):
 
             if len(self.server_ips) == 1:
                 with tempfile.NamedTemporaryFile() as script:
-                    script.write(resp % 'server2')
+                    script.write(resp % {'s_id': 2,
+                                         'server': 'server2'})
                     script.flush()
                     with tempfile.NamedTemporaryFile() as key:
                         key.write(private_key)
                         key.flush()
-                        commands.copy_file_to_host(script.name,
-                                                   "/tmp/script2", ip,
-                                                   username, key.name)
+                        self.copy_file_to_host(script.name,
+                                               "/tmp/script2", ip,
+                                               username, key.name)
                 cmd = start_server % {'port': self.port2,
                                       'script': 'script2'}
                 ssh_client.exec_command(cmd)
@@ -262,12 +300,19 @@ class BaseTestCase(manager.NetworkScenarioTest):
                         self.hm.get('id'),
                         load_balancer_id=self.load_balancer['id'])
 
-    def _create_pool(self, listener_id):
+    def _create_pool(self, listener_id, persistence_type=None,
+                     cookie_name=None):
         """Create a pool with ROUND_ROBIN algorithm."""
-        self.pool = self.pools_client.create_pool(
-            protocol='HTTP',
-            lb_algorithm='ROUND_ROBIN',
-            listener_id=listener_id)
+        pool = {
+            "listener_id": listener_id,
+            "lb_algorithm": "ROUND_ROBIN",
+            "protocol": "HTTP"
+        }
+        if persistence_type:
+            pool.update({'session_persistence': {'type': persistence_type}})
+        if cookie_name:
+            pool.update({'session_persistence': {"cookie_name": cookie_name}})
+        self.pool = self.pools_client.create_pool(**pool)
         self.assertTrue(self.pool)
         self.addCleanup(self._cleanup_pool, self.pool['id'],
                         load_balancer_id=self.load_balancer['id'])
@@ -337,7 +382,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
         # Check for floating ip status before you check load-balancer
         self.check_floating_ip_status(floating_ip, "ACTIVE")
 
-    def _create_load_balancer(self, ip_version=4):
+    def _create_load_balancer(self, ip_version=4, persistence_type=None):
         self.create_lb_kwargs = {'tenant_id': self.tenant_id,
                                  'vip_subnet_id': self.subnet['id']}
         self.load_balancer = self.load_balancers_client.create_load_balancer(
@@ -349,7 +394,8 @@ class BaseTestCase(manager.NetworkScenarioTest):
         listener = self._create_listener(load_balancer_id=load_balancer_id)
         self._wait_for_load_balancer_status(load_balancer_id)
 
-        self.pool = self._create_pool(listener_id=listener.get('id'))
+        self.pool = self._create_pool(listener_id=listener.get('id'),
+                                      persistence_type=persistence_type)
         self._wait_for_load_balancer_status(load_balancer_id)
 
         self._create_members(load_balancer_id=load_balancer_id,
@@ -372,7 +418,8 @@ class BaseTestCase(manager.NetworkScenarioTest):
         # vip port - see https://bugs.launchpad.net/neutron/+bug/1163569
         # However the linuxbridge-agent does, and it is necessary to add a
         # security group with a rule that allows tcp port 80 to the vip port.
-        self.network_client.update_port(
+#        self.network_client.update_port(
+        self.ports_client.update_port(
             self.load_balancer.get('vip_port_id'),
             security_groups=[self.security_group.id])
 
@@ -419,6 +466,25 @@ class BaseTestCase(manager.NetworkScenarioTest):
                       operating_status=operating_status))
         return lb
 
+    def _wait_for_pool_session_persistence(self, pool_id, sp_type=None):
+        interval_time = 1
+        timeout = 10
+        end_time = time.time() + timeout
+        while time.time() < end_time:
+            pool = self.pools_client.get_pool(pool_id)
+            sp = pool.get('session_persistence', None)
+            if (not (sp_type or sp) or
+                    pool['session_persistence']['type'] == sp_type):
+                return pool
+            time.sleep(interval_time)
+        raise Exception(
+            _("Wait for pool ran for {timeout} seconds and did "
+              "not observe {pool_id} update session persistence type "
+              "to {type}.").format(
+                  timeout=timeout,
+                  pool_id=pool_id,
+                  type=sp_type))
+
     def _check_load_balancing(self):
         """
         1. Send NUM requests on the floating ip associated with the VIP
@@ -442,7 +508,7 @@ class BaseTestCase(manager.NetworkScenarioTest):
                 return False
             except error.HTTPError:
                 return False
-        timeout = config.compute.ping_timeout
+        timeout = config.validation .ping_timeout
         start = time.time()
         while not try_connect(check_ip, port):
             if (time.time() - start) > timeout:
@@ -480,3 +546,74 @@ class BaseTestCase(manager.NetworkScenarioTest):
         counters = self._send_requests(self.vip_ip, ["server1", "server2"])
         for member, counter in six.iteritems(counters):
             self.assertEqual(counter, 0, 'Member %s is balanced' % member)
+
+    def _check_source_ip_persistence(self):
+        """Check source ip session persistence.
+
+        Verify that all requests from our ip are answered by the same server
+        that handled it the first time.
+        """
+        # Check that backends are reachable
+        self._check_connection(self.vip_ip)
+
+        resp = []
+        for count in range(10):
+            resp.append(
+                urllib2.urlopen("http://{0}/".format(self.vip_ip)).read())
+        self.assertEqual(len(set(resp)), 1)
+
+    def _update_pool_session_persistence(self, persistence_type=None,
+                                         cookie_name=None):
+        """Update a pool with new session persistence type and cookie name."""
+
+        update_data = {}
+        if persistence_type:
+            update_data = {"session_persistence": {
+                "type": persistence_type}}
+        if cookie_name:
+            update_data['session_persistence'].update(
+                {"cookie_name": cookie_name})
+        self.pools_client.update_pool(self.pool['id'], **update_data)
+        self.pool = self._wait_for_pool_session_persistence(self.pool['id'],
+                                                            persistence_type)
+        self._wait_for_load_balancer_status(self.load_balancer['id'])
+        if persistence_type:
+            self.assertEqual(persistence_type,
+                             self.pool['session_persistence']['type'])
+        if cookie_name:
+            self.assertEqual(cookie_name,
+                             self.pool['session_persistence']['cookie_name'])
+
+    def _check_cookie_session_persistence(self):
+        """Check cookie persistence types by injecting cookies in requests."""
+
+        # Send first request and get cookie from the server's response
+        cj = cookielib.CookieJar()
+        opener = urllib2.build_opener(urllib2.HTTPCookieProcessor(cj))
+        opener.open("http://{0}/".format(self.vip_ip))
+        resp = []
+        # Send 10 subsequent requests with the cookie inserted in the headers.
+        for count in range(10):
+            request = urllib2.Request("http://{0}/".format(self.vip_ip))
+            cj.add_cookie_header(request)
+            response = urllib2.urlopen(request)
+            resp.append(response.read())
+        self.assertEqual(len(set(resp)), 1, message=resp)
+
+    def copy_file_to_host(self, file_from, dest, host, username, pkey):
+        dest = "%s@%s:%s" % (username, host, dest)
+        cmd = ("scp -v -o UserKnownHostsFile=/dev/null "
+               "-o StrictHostKeyChecking=no "
+               "-i %(pkey)s %(file1)s %(dest)s" % {'pkey': pkey,
+                                                   'file1': file_from,
+                                                   'dest': dest})
+        args = shlex.split(cmd.encode('utf-8'))
+        subprocess_args = {'stdout': subprocess.PIPE,
+                           'stderr': subprocess.STDOUT}
+        proc = subprocess.Popen(args, **subprocess_args)
+        stdout, stderr = proc.communicate()
+        if proc.returncode != 0:
+            LOG.error(("Command {0} returned with exit status {1},"
+                      "output {2}, error {3}").format(cmd, proc.returncode,
+                                                      stdout, stderr))
+        return stdout
